@@ -9,12 +9,9 @@ from typing import Union
 import os
 from pathlib import Path
 
-cwd = Path(__file__).parents[0]
-cwd = str(cwd)
-
 __all__ = ["Bot"]
 
-__version__ = "0.0.9"
+__version__ = "1.0.1"
 
 class BaseBot(commands.Bot):
 	def __init__(self, *args, **kwargs):
@@ -26,9 +23,9 @@ class Bot(BaseBot):
 	"""
 	def __init__(self, *args, **kwargs):
 		super().__init__(*args, **kwargs)
-		self.cog_list = ["cogs.fun", "cogs.misc", "jishaku"]
+		self.cog_list = ["jishaku"]
 	
 	async def on_ready(self):
 		for ext in self.cog_list:
 			self.load_extension(ext)
-		print(f"{'-' * 20}\nID: {self.userr.id}\nName: {self.user}")		
\ No newline at end of file
+		print(f"{'-' * 20}\nID: {self.user.id}\nName: {self.user}")		
\ No newline at end of file
